import { Component, OnInit } from "@angular/core";
import { ActivatedRoute, Router } from "@angular/router";
import { Queries } from "../../../../models/graphql/queries.model";
import { UserListQuery } from "../../../../models/graphql/query.model";
import { SpinnerService } from "../../../../services/spinner/spinner.service";
import { DataService } from "../../../../services/data/data.service";
import { User } from "../../../../models/data/user.model";

@Component({
  selector: "app-profile",
  templateUrl: "./profile.component.html",
  styleUrls: ["./profile.component.scss"]
})
export class ProfileComponent implements OnInit {

  user!: User;

  constructor(
    private route: ActivatedRoute,
    private router: Router,
    private spinner: SpinnerService,
    private data: DataService
  ) {
  }

  ngOnInit() {
    this.data.getServerFromRoute(this.route);

    this.spinner.showSpinner();
    if (!this.route.snapshot.params["memberId"]) {
      this.spinner.hideSpinner();
      this.router.navigate(["/dashboard"]);
      return;
    }

    this.data.query<User>(Queries.singleUserQuery, {
        filter: {
          id: this.route.snapshot.params["memberId"],
          leftServer: false
        }
      },
      function(data: UserListQuery) {
        return data.users.length > 0 ? data.users[0] : null;
      }
    ).subscribe(user => {
      this.user = user;
      console.log(this.user);
      this.spinner.hideSpinner();
    });
  }
}
